@@ -11,8 +11,10 @@ import sys
 from collections.abc import Iterable
 from html.parser import HTMLParser
 from typing import Any, Self
+from urllib.parse import urlparse
 
 import requests
+from bs4 import BeautifulSoup
 
 from univention.config_registry import ConfigRegistry
 from univention.lib.umc import Client as _Client
@@ -124,3 +126,67 @@ class ClientSaml(Client):
         relay_state = get_html_tag_value(saml_idp_login_ans.text, 'input', ('name', 'RelayState'), 'value')
         print('Post SAML msg to: %s' % sp_login_url)
         self.__samlSession.post(sp_login_url, data={'SAMLResponse': saml_msg, 'RelayState': relay_state}).raise_for_status()
+
+
+class ClientOIDC(Client):
+
+    def authenticate(
+        self,
+        username: str,
+        password: str,
+        portal_fqdn: str | None = None,
+        kc_idp_hint: str | None = None,
+    ) -> None:
+        self.session = requests.Session()
+        server = portal_fqdn or self.hostname
+        url = f'https://{server}/univention/oidc/'
+        # kerberos redirect
+        res = self.session.get(url)
+        kerberos_redirect_url = self.get_kerberos_redirect(res.text)
+        assert kerberos_redirect_url, res.text
+        # external idp
+        if kc_idp_hint:
+            res = self.session.get(kerberos_redirect_url, params={'kc_idp_hint': kc_idp_hint})
+            # kerberos redirect
+            kerberos_redirect_url = self.get_kerberos_redirect(res.text)
+            assert kerberos_redirect_url, res.text
+        res = self.session.get(kerberos_redirect_url)
+        login_link = self.get_login_link(res)
+        self.auth_server = urlparse(login_link).netloc
+        # login
+        params = {'username': username, 'password': password}
+        res = self.session.post(login_link, data=params)
+        assert res.status_code == 200, res.text
+        assert 'authentication has failed' not in res.text, res.text
+        self.cookies.update(self.session.cookies.items())
+
+    def logout(self) -> None:
+        url = f'https://{self.auth_server}/realms/ucs/protocol/openid-connect/logout'
+        res = self.session.get(url, verify=False)
+        assert res.status_code == 200, res.text
+        session_code, url = self.get_session_code(res.text)
+        res = self.session.post(f'https://{self.auth_server}{url}', data={'session_code': session_code}, verify=False)
+        assert res.status_code == 200, res.text
+
+    def get_session_code(self, text):
+        try:
+            soup = BeautifulSoup(text, 'lxml')
+            url = soup.find('form', {'method': 'POST'}).attrs['action']
+            session_code = soup.find('input', {'name': 'session_code'}).attrs['value']
+            return session_code, url
+        except AttributeError:
+            return None, None
+
+    def get_kerberos_redirect(self, text):
+        try:
+            soup = BeautifulSoup(text, 'lxml')
+            title = soup.find('title')
+            if title and 'Kerberos' in title.text:
+                return soup.find('body').findChild('form').attrs.get('action')
+        except AttributeError:
+            return None
+
+    def get_login_link(self, req):
+        soup = BeautifulSoup(req.text, features='lxml')
+        login_link = soup.select_one('form[id="kc-form-login"]')['action']
+        return login_link
